// tone library example
program tone_example

device = 18F26K22
clock = 64

// int osc and IO pin libraries
include "intosc.bas"
#option DIGITALIO_INIT = true       // automatically call setalldigital
#option DIGITALIO_SLEWRATE = 1      // 1=slow (we don't need fast edges)
include "setdigitalio.bas"

// tone library options
// specify output pin
#option TONE_OUTPUT_PIN = PORTC.2
// wait flag setting (default = false)
'#option TONE_WAIT = true
include "tone.bas"

// star wars imperial march using individual tone play calls
sub Play_Imperial_March()
    tone.setwait()

    tone.play(NOTE_A4, 500)  
    tone.play(NOTE_A4, 500)  
    tone.play(NOTE_A4, 500)  
    tone.play(NOTE_F4, 350)  
    tone.play(NOTE_C5, 150)  
    tone.play(NOTE_A4, 500)  
    tone.play(NOTE_F4, 350)  
    tone.play(NOTE_C5, 150)  
    tone.play(NOTE_A4, 1000)  
    tone.play(NOTE_PAUSE, 250)  

    tone.play(NOTE_E5, 500)  
    tone.play(NOTE_E5, 500)  
    tone.play(NOTE_E5, 500)  
    tone.play(NOTE_F5, 350)  
    tone.play(NOTE_C5, 150)  
    tone.play(NOTE_GS4, 500)  
    tone.play(NOTE_F4, 350)  
    tone.play(NOTE_C5, 150)  
    tone.play(NOTE_A4, 1000)  
    tone.play(NOTE_PAUSE, 250)  
end sub

// const array of (freq, duration) note pairs
const Imperial_March(20*2) as word = 
(
    NOTE_A4, 500,  
    NOTE_A4, 500,  
    NOTE_A4, 500,  
    NOTE_F4, 350,  
    NOTE_C5, 150,  
    NOTE_A4, 500,  
    NOTE_F4, 350,  
    NOTE_C5, 150,  
    NOTE_A4, 1000,  
    NOTE_PAUSE, 250,  

    NOTE_E5, 500,  
    NOTE_E5, 500,  
    NOTE_E5, 500,  
    NOTE_F5, 350,  
    NOTE_C5, 150,  
    NOTE_GS4, 500,  
    NOTE_F4, 350,  
    NOTE_C5, 150,  
    NOTE_A4, 1000,  
    NOTE_PAUSE, 250
)

dim ix as byte
dim note as word
dim num_notes as word

// note list in ram (freq, duration pairs) 
dim note_list(64*2) as word

main:
    // init tone library module
    tone.init()
    
    // play a note until stop()
    tone.play(NOTE_A4)      // tone A (440) will play forever...
    delayms(1000)           // allow note to play for 1sec
    tone.stop()             // and now stop it

    // tone.play defaults to non-blocking mode...
    // it returns immediately and does not wait
    tone.setwait(false)         // this is the tone library default setting
    tone.play(NOTE_G4, 500)     // play G for 500ms
    tone.wait()                 // wait for note to finish

    // set play to blocking mode...
    // it now returns when done and no need to call wait
    // (you can change the tone library default using '#option TONE_WAIT = true')
    tone.setwait()              // set wait_flag true
    tone.play(NOTE_A4, 100)     // play A for 100ms
    
    // play all 88 piano notes defined in the tone module for 250ms each
    for ix = 0 to bound(tone.notes)
        note = tone.notes(ix)       // get note from the list
        tone.play(note, 250)        // play note for 250ms
        delayms(10)                 // short delay between notes
    next

    // play a tune using individual calls (long winded approach)
    Play_Imperial_March()

    // array functions
    // play a const array of notes
    tone.play(Imperial_March)

    // play first 9 notes from the const array
    tone.play(Imperial_March, 9)

    // play an array of notes in ram
    clear(note_list)
    note_list = Imperial_March                  // copy the const array to ram
    num_notes = NOTE_COUNT(Imperial_March)      // get number of notes defined in the const array
    tone.play(note_list, num_notes)             // play entire tune

    // play first 9 notes from the array in ram
    tone.play(note_list, 9)
    
    while (true)
    end while

end program

    
